@@ -53,10 +53,10 @@ typedef float gkick_real;
 
 #define GEONKICK_UNUSED(expr) (void)expr
 
-#define GEONKICK_VERSION 0x020702
+#define GEONKICK_VERSION 0x020902
 #define GEONKICK_NAME "Geonkick"
 #define GEONKICK_APP_NAME "geonkick"
-#define GEOKICK_VERSION_STRING "2.7.2"
+#define GEOKICK_VERSION_STRING "2.9.2"
 
 #ifdef GEONKICK_AUDIO_JACK
 #define GKICK_IS_STANDALONE (1)
@@ -687,6 +687,12 @@ geonkick_set_preview_sample(struct geonkick *kick,
 void
 geonkick_play_sample_preview(struct geonkick *kick);
 
+enum geonkick_error
+geonkick_set_sample_preview_limiter(struct geonkick *kick, gkick_real val);
+
+enum geonkick_error
+geonkick_get_sample_preview_limiter(struct geonkick *kick, gkick_real *val);
+
 bool
 geonkick_is_plugin();
 
