@@ -36,7 +36,8 @@ Envelope::Envelope(const RkRect &area)
 			 Type::Frequency,
 			 Type::FilterCutOff,
                          Type::DistortionDrive,
-                         Type::DistortionVolume})
+                         Type::DistortionVolume,
+                         Type::PitchShift})
         , overPointIndex{0}
         , isOverPoint{false}
         , pointSelected{false}
@@ -120,14 +121,26 @@ void Envelope::drawTimeScale(RkPainter &painter)
 void Envelope::drawValueScale(RkPainter &painter)
 {
         std::string text;
-        if (type() == Type::Amplitude)
+        switch (type()) {
+        case Type::Amplitude:
                 text = "Amplitude";
-	else if (type() == Type::DistortionDrive)
+                break;
+        case Type::DistortionDrive:
 		text = "Distortion Drive";
-        else if (type() == Type::DistortionVolume)
+                break;
+        case Type::DistortionVolume:
                 text = "Distortion Volume";
-        else if (type() == Type::Frequency || type() == Type::FilterCutOff)
+                break;
+        case Type::Frequency:
+        case Type::FilterCutOff:
                 text = "Frequency, Hz";
+                break;
+        case Type::PitchShift:
+                text = "Semitones";
+                break;
+        default:
+                text = "Unknown";
+        }
 
         painter.translate(RkPoint(getOrigin().x() - 30, getOrigin().y() - H() / 2 + 35));
         painter.rotate(-M_PI / 2);
@@ -160,9 +173,26 @@ void Envelope::drawValueScale(RkPainter &painter)
                         painter.setPen(RkPen(RkColor(110, 110, 110)));
                         std::ostringstream ss;
 			if ( type() == Type::DistortionDrive || type() == Type::DistortionVolume)
-				ss << std::setprecision(2) << i * step * pow(10, 36.0/20);
+				ss << std::fixed << std::setprecision(2) << i * step * pow(10, 36.0/20);
 			else
-				ss << std::setprecision(2) << i * step;
+				ss << std::fixed << std::setprecision(2) << i * step;
+                        painter.drawText(rect, ss.str(), Rk::Alignment::AlignRight);
+                }
+        } else if (type() == Type::PitchShift && envelopeAmplitude() > std::numeric_limits<double>::min()) {
+                double step = 2 * std::abs(envelopeAmplitude() / 10);
+                double amplitude = 2 * std::abs(envelopeAmplitude());
+                for (int i = 1; i <= 10; i++) {
+                        int x = getOrigin().x();
+                        int y = 0;
+                        y = getOrigin().y() - H() * (i * step / amplitude);
+                        RkPen pen(RkColor(80, 80, 80));
+                        pen.setStyle(RkPen::PenStyle::DotLine);
+                        painter.setPen(pen);
+                        painter.drawLine(x + 1, y, x + W(), y);
+                        RkRect rect(x - 28,  y -  rectH / 2, 22, rectH);
+                        painter.setPen(RkPen(RkColor(110, 110, 110)));
+                        std::ostringstream ss;
+                        ss << std::fixed << std::setprecision(1) << i * step - amplitude / 2;
                         painter.drawText(rect, ss.str(), Rk::Alignment::AlignRight);
                 }
         } else if (type() == Type::Frequency || type() == Type::FilterCutOff) {
@@ -220,7 +250,7 @@ void Envelope::drawPoints(RkPainter &painter)
                 scaledPoint = RkPoint(scaledPoint.x() + origin.x(), origin.y() - scaledPoint.y());
 		drawPoint(painter, scaledPoint);
                 scaledPoint = RkPoint(scaledPoint.x(), scaledPoint.y() - 1.4 * getPointRadius());
-                drawPointValue(painter, scaledPoint, envelopePoints[i].y() * envelopeAmplitude());
+                drawPointValue(painter, scaledPoint, envelopePoints[i].y());
         }
 }
 
@@ -235,13 +265,20 @@ void Envelope::drawPointValue(RkPainter &painter, const RkPoint &point, double v
         if (type() == Envelope::Type::Amplitude
             || type() == Type::DistortionDrive
             || type() == Type::DistortionVolume) {
+                value *= envelopeAmplitude();
                 std::ostringstream ss;
 		if (type() == Type::DistortionDrive || type() == Type::DistortionVolume)
 			ss << std::setprecision(2) << value * pow(10, 36.0 / 20);
 		else
 			ss << std::setprecision(2) << value;
                 painter.drawText(point.x(), point.y(), ss.str());
+        } else if (type() == Type::PitchShift) {
+                value *= envelopeAmplitude();
+                std::ostringstream ss;
+                ss << std::fixed << std::setprecision(1) << 2 * value - envelopeAmplitude();
+                painter.drawText(point.x(), point.y(), ss.str());
         } else if (type() == Envelope::Type::Frequency || type() == Type::FilterCutOff) {
+                value *= envelopeAmplitude();
                 if (value < 20)
                         painter.drawText(point.x(), point.y(), "20Hz " + frequencyToNote(20));
                 if (value >= 20 && value < 1000) {
@@ -478,7 +515,8 @@ RkRealPoint Envelope::scaleDown(const RkPoint &point)
         RkRealPoint scaledPoint;
         if (type() == Type::Amplitude
             || type() == Type::DistortionDrive
-            || type() == Type::DistortionVolume) {
+            || type() == Type::DistortionVolume
+            || type() == Type::PitchShift) {
                 scaledPoint = RkRealPoint(static_cast<double>(point.x()) / W(),
                                           static_cast<double>(point.y()) / H());
         } else {
@@ -496,7 +534,8 @@ RkPoint Envelope::scaleUp(const RkRealPoint &point)
         int x, y;
         if (type() == Type::Amplitude
             || type() == Type::DistortionDrive
-            || type() == Type::DistortionVolume) {
+            || type() == Type::DistortionVolume
+            || type() == Type::PitchShift) {
                 x = point.x() * W();
                 y = point.y() * H();
         } else {
@@ -545,47 +584,23 @@ void Envelope::setDotRadius(int radius)
 
 std::string Envelope::frequencyToNote(rk_real f)
 {
-        if (f < 16.35160 || f > 7902.133)
+        if (f < 27.50 || f > 13289.75)
                 return "";
-
-        int n = 0;
-        while (f > 32.70320) {
-                f /= 2;
-                n++;
-        }
-
-        int octave = n;
-        std::vector<double> pitches {
-		        16.35160,
-                        17.32391,
-                        18.35405,
-			19.44544,
-                        20.60172,
-                        21.82676,
-                        23.12465,
-                        24.49971,
-                        25.95654,
-                        27.50000,
-                        29.13524,
-                        30.86771};
-	std::vector<std::string> notes{
-		        "C",
-			"C#",
-			"D",
-			"D#",
-			"E",
-			"F",
-			"F#",
-			"G",
-			"G#",
-			"A",
-			"A#",
-			"B"};
-        n = 12;
-        while (--n && pitches[n] > f);
-        if (n < 11 && f > (pitches[n + 1] - pitches[n]) / 2)
-                n++;
-
-        return "(" + notes[n] + std::to_string(octave) + ")";
+        constexpr std::array<const char*, 12> noteNames = {"C",
+                                                           "C#",
+                                                           "D",
+                                                           "D#",
+                                                           "E",
+                                                           "F",
+                                                           "F#",
+                                                           "G",
+                                                           "G#",
+                                                           "A",
+                                                           "A#",
+                                                           "B"};
+        int midiNote  = 12 * (log2(f / 27.5)) + 21;
+        int octave    = midiNote / 12 - 1;
+        int noteIndex = midiNote % 12;
+        return noteNames[noteIndex] + std::to_string(octave);
 }
 
