@@ -40,9 +40,11 @@ KickGraph::KickGraph(RkObject *parent, GeonkickApi *api, const RkSize &size)
 
 KickGraph::~KickGraph()
 {
-        isRunning = false;
-        threadConditionVar.notify_one();
-        graphThread->join();
+        if (graphThread) {
+                isRunning = false;
+                threadConditionVar.notify_one();
+                graphThread->join();
+        }
 }
 
 void KickGraph::start()
@@ -65,7 +67,7 @@ void KickGraph::updateGraphBuffer()
 void KickGraph::drawKickGraph()
 {
         while (isRunning) {
-                // Ignore too many updates. The last udpate will be processed.
+                // Ignore too many updates. The last update will be processed.
                 std::this_thread::sleep_for(std::chrono::milliseconds(60));
                 std::unique_lock<std::mutex> lock(graphMutex);
                 if (!updateGraph)
